==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/gsw-FR.pl <==
{
  am_pm_abbreviated => [
    "vorm.",
    "nam."
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "H",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    MMMMEd => "E d. MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMd => "d.MM.",
    MMdd => "dd.MM.",
    Md => "d.M.",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "y-M",
    yMEd => "E, y-M-d",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E, d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMMdd => "dd.MM.y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "gsw-FR",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "dd.MM.y",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "M\N{U+00e4}.",
    "Zi.",
    "Mi.",
    "Du.",
    "Fr.",
    "Sa.",
    "Su."
  ],
  day_format_narrow => [
    "M",
    "D",
    "M",
    "D",
    "F",
    "S",
    "S"
  ],
  day_format_wide => [
    "M\N{U+00e4}\N{U+00e4}ntig",
    "Ziischtig",
    "Mittwuch",
    "Dunschtig",
    "Friitig",
    "Samschtig",
    "Sunntig"
  ],
  day_stand_alone_abbreviated => [
    "M\N{U+00e4}.",
    "Zi.",
    "Mi.",
    "Du.",
    "Fr.",
    "Sa.",
    "Su."
  ],
  day_stand_alone_narrow => [
    "M",
    "D",
    "M",
    "D",
    "F",
    "S",
    "S"
  ],
  day_stand_alone_wide => [
    "M\N{U+00e4}\N{U+00e4}ntig",
    "Ziischtig",
    "Mittwuch",
    "Dunschtig",
    "Friitig",
    "Samschtig",
    "Sunntig"
  ],
  era_abbreviated => [
    "v. Chr.",
    "n. Chr."
  ],
  era_narrow => [
    "v. Chr.",
    "n. Chr."
  ],
  era_wide => [
    "v. Chr.",
    "n. Chr."
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Swiss German",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "M\N{U+00e4}r",
    "Apr",
    "Mai",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Okt",
    "Nov",
    "Dez"
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_format_wide => [
    "Januar",
    "Februar",
    "M\N{U+00e4}rz",
    "April",
    "Mai",
    "Juni",
    "Juli",
    "Auguscht",
    "Sept\N{U+00e4}mber",
    "Oktoober",
    "Nov\N{U+00e4}mber",
    "Dez\N{U+00e4}mber"
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "M\N{U+00e4}r",
    "Apr",
    "Mai",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Okt",
    "Nov",
    "Dez"
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "Januar",
    "Februar",
    "M\N{U+00e4}rz",
    "April",
    "Mai",
    "Juni",
    "Juli",
    "Auguscht",
    "Sept\N{U+00e4}mber",
    "Oktoober",
    "Nov\N{U+00e4}mber",
    "Dez\N{U+00e4}mber"
  ],
  name => "Swiss German France",
  native_language => "Schwiizert\N{U+00fc}\N{U+00fc}tsch",
  native_name => "Schwiizert\N{U+00fc}\N{U+00fc}tsch Frankriich",
  native_script => undef,
  native_territory => "Frankriich",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "1. Quartal",
    "2. Quartal",
    "3. Quartal",
    "4. Quartal"
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "1. Quartal",
    "2. Quartal",
    "3. Quartal",
    "4. Quartal"
  ],
  script => undef,
  territory => "France",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/gsw-FR.pl <==
{
  am_pm_abbreviated => [
    "vorm.",
    "nam.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "H",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    MMMMEd => "E d. MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMd => "d.MM.",
    MMdd => "dd.MM.",
    Md => "d.M.",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "y-M",
    yMEd => "E, y-M-d",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E, d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMMdd => "dd.MM.y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "gsw-FR",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "dd.MM.y",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "M\N{U+00e4}.",
    "Zi.",
    "Mi.",
    "Du.",
    "Fr.",
    "Sa.",
    "Su.",
  ],
  day_format_narrow => [
    "M",
    "D",
    "M",
    "D",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "M\N{U+00e4}\N{U+00e4}ntig",
    "Ziischtig",
    "Mittwuch",
    "Dunschtig",
    "Friitig",
    "Samschtig",
    "Sunntig",
  ],
  day_stand_alone_abbreviated => [
    "M\N{U+00e4}.",
    "Zi.",
    "Mi.",
    "Du.",
    "Fr.",
    "Sa.",
    "Su.",
  ],
  day_stand_alone_narrow => [
    "M",
    "D",
    "M",
    "D",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "M\N{U+00e4}\N{U+00e4}ntig",
    "Ziischtig",
    "Mittwuch",
    "Dunschtig",
    "Friitig",
    "Samschtig",
    "Sunntig",
  ],
  era_abbreviated => [
    "v. Chr.",
    "n. Chr.",
  ],
  era_narrow => [
    "v. Chr.",
    "n. Chr.",
  ],
  era_wide => [
    "v. Chr.",
    "n. Chr.",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Swiss German",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "M\N{U+00e4}r",
    "Apr",
    "Mai",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Okt",
    "Nov",
    "Dez",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Januar",
    "Februar",
    "M\N{U+00e4}rz",
    "April",
    "Mai",
    "Juni",
    "Juli",
    "Auguscht",
    "Sept\N{U+00e4}mber",
    "Oktoober",
    "Nov\N{U+00e4}mber",
    "Dez\N{U+00e4}mber",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "M\N{U+00e4}r",
    "Apr",
    "Mai",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Okt",
    "Nov",
    "Dez",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Januar",
    "Februar",
    "M\N{U+00e4}rz",
    "April",
    "Mai",
    "Juni",
    "Juli",
    "Auguscht",
    "Sept\N{U+00e4}mber",
    "Oktoober",
    "Nov\N{U+00e4}mber",
    "Dez\N{U+00e4}mber",
  ],
  name => "Swiss German France",
  native_language => "Schwiizert\N{U+00fc}\N{U+00fc}tsch",
  native_name => "Schwiizert\N{U+00fc}\N{U+00fc}tsch Frankriich",
  native_script => undef,
  native_territory => "Frankriich",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. Quartal",
    "2. Quartal",
    "3. Quartal",
    "4. Quartal",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. Quartal",
    "2. Quartal",
    "3. Quartal",
    "4. Quartal",
  ],
  script => undef,
  territory => "France",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}
